===========
 Changelog
===========

Version 0.1.5
-------------

- Making an exception for forcing second factor for paths containing ``STATIC_URL``

Version 0.1.4
-------------

- Adding some more logging

Version 0.1.3
-------------

- Added support for username remapping via the ``USERNAME_REMAPPER`` option
  for entries in ``DUO_CONFIG``.

Version 0.1.2
-------------

First public release.
